instrumenttools.Harpsichord
===========================

.. abjad-lineage:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord

.. autoclass:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Harpsichord.Harpsichord.Harpsichord.__repr__
   :noindex:
